@@ -1,3 +1,4 @@
+import json
 import re
 from typing import Dict, Union, List
 
@@ -24,7 +25,7 @@ def _fine_tune_results(
                     r"^(\. )|^([\d]{1,3}(\.|,)? ?)", "", v2["text"]
                 )
                 single_row.append(clean_text)
-            v1["row_count"] = int(k1) + 1
+            # v1["row_count"] = int(k1) + 1
             if len("".join(single_row)) > 3:
                 rows.append(v1)
         v["rows"] = rows
@@ -99,4 +100,5 @@ def _fine_tune_results(
         if "ad" in d1["text"]:
             d1["text"] = "Buy (add'l)"
         count += 1
-    return results
+
+    return json.loads(json.dumps(results).replace("\\u2022", "-1"))
